import FreeCAD as App
import FreeCADGui as Gui

from kipy import KiCad

from . import settings
from .bases import BaseObject, BaseViewProvider

class APIObject(BaseObject):
    TYPE = 'KiConnect::API'

    def __init__(self, feature):
        super(APIObject, self).__init__(feature)

        feature.addProperty('App::PropertyFile', 'Socket', 'KiConnect', 'Path to the KiCAD Socket File').Socket = '/tmp/kicad/api.lock'
        feature.addProperty('App::PropertyBool', 'Connected', 'KiConnect', 'Is socket connected')

        self.onDocumentRestored(feature)

    def onDocumentRestored(self, feature):
        super(APIObject, self).onDocumentRestored(feature)

        self.kicad = KiCad()
        self.ping_connection(feature)

        parent = feature.getParent()
        if not parent: return

        boards = [ board for board in parent.Group if hasattr(board, 'Type') and board.Type == 'KiConnect::Board' ]


    @property
    def is_connected(self):
        return self.feature.Connected

    def ping_connection(self, feature):
        try:
            self.kicad.ping()
            feature.Connected = True
            feature.Label2 = 'Connected'
        except Exception as e:
            print(e)
            feature.Connected = False
            feature.Label2 = 'Disconnected'
    pass


class APIViewProvider(BaseViewProvider):
    ICON = 'icon_footprint_browser.svg'
    TYPE = 'KiConnect::API'

    def __init__(self, viewprovider):
        super(APIViewProvider, self).__init__(viewprovider)


def makeAPI(parent):
    feature = App.ActiveDocument.addObject('App::FeaturePython', 'API')
    parent.addObject(feature)

    APIObject(feature)
    APIViewProvider(feature.ViewObject)

    return feature
